------------
Known Issues
------------

    * Creating a Jp2 file with the irreversible option does not work
      on windows.
    * Eval-ing a :py:meth:`repr` string does not work on windows.

-------
Roadmap
-------

Here's an incomplete list of what I'd like to focus on in the future.

    * continue to monitor upstream changes in the openjp2 library
